==> nextcloud-app-tasks-0.11.2-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/tasks/l10n/es_MX.js <==
OC.L10N.register(
    "tasks",
    {
    "Tasks" : "Tareas",
    "Important" : "Importante",
    "Today" : "Hoy",
    "Week" : "Semana",
    "All" : "Todos",
    "Current" : "Actual",
    "Completed" : "Completado",
    "The Tasks app for Nextcloud" : "Una aplicación de Tareas para Nextcloud",
    "Once enabled, a new Tasks menu will appear in your Nextcloud apps menu. From there you can add and delete tasks, edit their title, description, start and due dates, reminder times, mark them as important, and add comments on them. Tasks can be shared between users. Tasks can be synchronized using CalDav (each task list is linked to an Nextcloud calendar, to sync it to your local client - Thunderbird, Evolution, KDE Kontact, iCal... - just add the calendar as a remote calendar in you client). You can download your tasks as ICS files using the download button for each calendar." : "Una vez habilitada, un nuevo menú de Tareas aparecerá en tu menú de aplicaciones de Nextcloud. De ahí, pudes agregar o borrar tareas, editar el título, descripción, fechas de incio y fin, tiempos de recordatorios, marcarlas como importantes y agregarles comentarios. Las tareas se pueden compartir entre usuarios. Las tareas se pueden sincrionizar usando CalDav (cada tarea está ligada a un calendario Nextcloud, para sincronizarla con tu cliente local - Thunderbird, Evolution, KDE Kontact, iCal... - solo agrega el calendario como un calendrio remoto en tu cliente). Puedes descargar tus tareas como archivos ICS usando el botón de descargar para cada calendario.",
    "Delete" : "Borrar",
    "Cancel" : "Cancelar",
    "Change sort order" : "Cambiar el criterio para ordenar",
    "Default" : "Predeterminado",
    "Due date" : "Fecha de vencimiento",
    "Start date" : "Fecha de inicio",
    "Priority" : "Prioridad",
    "Manually" : "Manualmente",
    "Alphabetically" : "Alfabéticamente",
    "Task is completed" : "La tarea ha sido completada",
    "_%n Completed Task_::_%n Completed Tasks_" : ["%n Tarea Completada","%n Tareas Completadas"],
    "Tomorrow" : "Mañana",
    "Set start date" : "Establecer fecha de inicio",
    "Set due date" : "Establecer fecha de vencimiento",
    "All day" : "Todo el día",
    "Task not found!" : "¡Tarea no encontrada!",
    "Edit" : "Editar",
    "Download" : "Descargar",
    "Save" : "Guardar",
    "New List" : "Nueva Lista",
    "An empty name is not allowed." : "No se permite un nombre vacío.",
    "Settings" : "Configuraciones ",
    "Visibility of Smart Collections" : "Visibilidad de Colecciones Inteligentes",
    "Hidden" : "Oculto",
    "Visible" : "Visible",
    "Automatic" : "Automático"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-app-tasks-0.14.4-2-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/tasks/l10n/es_MX.js <==
OC.L10N.register(
    "tasks",
    {
    "Important" : "Importante",
    "Today" : "Hoy",
    "Week" : "Semana",
    "All" : "Todos",
    "Current" : "Actual",
    "Completed" : "Completado",
    "Tasks" : "Tareas",
    "The Tasks app for Nextcloud" : "Una aplicación de Tareas para Nextcloud",
    "Visibility of Smart Collections" : "Visibilidad de Colecciones Inteligentes",
    "Hidden" : "Oculto",
    "Visible" : "Visible",
    "Automatic" : "Automático",
    "Share with users or groups" : "Compartir con otros usuarios o grupos",
    "Edit" : "Editar",
    "Delete" : "Borrar",
    "Unshare" : "Dejar de compartir",
    "Cancel" : "Cancelar",
    "Save" : "Guardar",
    "An empty name is not allowed." : "No se permite un nombre vacío.",
    "Change sort order" : "Cambiar el criterio para ordenar",
    "Start date" : "Fecha de inicio",
    "Due date" : "Fecha de vencimiento",
    "Last modified" : "Última modificación",
    "Priority" : "Prioridad",
    "Alphabetically" : "Alfabéticamente",
    "Manually" : "Manualmente",
    "Task is completed" : "La tarea ha sido completada",
    "_%n Completed Task_::_%n Completed Tasks_" : ["%n Tarea Completada","%n Tareas Completadas"],
    "Tomorrow" : "Mañana",
    "New List" : "Nueva Lista",
    "All day" : "Todo el día",
    "When shared show full event" : "Al compartir, mostrar el evento completo",
    "When shared show only busy" : "Al compartir, mostrar sólo como ocupado ",
    "When shared hide this event" : "Al compartir, ocultar este evento ",
    "Canceled" : "Cancelada",
    "Task not found!" : "¡Tarea no encontrada!",
    "Set start date" : "Establecer fecha de inicio",
    "Set due date" : "Establecer fecha de vencimiento",
    "An error occurred" : "Ha ocurrido un error"
},
"nplurals=2; plural=(n != 1);");
